MethodChannelMydidIntegration class

An implementation of MydidIntegrationPlatform that uses method channels.

Inheritance

Properties

apps Future<List>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
override
isDidInstalled() Future<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

showAleartDialog → dynamic
no setter

Constants

methodChannel → const MethodChannel
The method channel used to interact with the native platform.