MethodChannelMydidIntegration class
An implementation of MydidIntegrationPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- MydidIntegrationPlatform
- MethodChannelMydidIntegration
Constructors
Properties
Methods
-
getPlatformVersion(
) → Future< String?> -
override
-
isDidInstalled(
) → Future< String> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- showAleartDialog → dynamic
-
no setter
Constants
- methodChannel → const MethodChannel
- The method channel used to interact with the native platform.